from selenium import webdriver
from webdriver_manager.chrome import ChromeDriverManager
import time
import os

BASE_DIR = os.path.dirname(os.path.realpath(__file__))
html_location = os.path.join(BASE_DIR, 'html')

for i in range(21,30):
    driver = webdriver.Chrome(ChromeDriverManager().install())
    url = f"https://www.amazon.com/E12SV-Single-Carpeted-Subwoofer-Enclosure/product-reviews/B0013N0UEE/ref=cm_cr_arp_d_paging_btm_next_2?ie=UTF8&reviewerType=all_reviews&pageNumber={i}"
    print(url)
    driver.get(url)
    file_path = os.path.join(html_location,str(i)+".html")
    with open(file_path, "w") as f:
        f.write(driver.page_source)
    time.sleep(5)
    driver.close()



import os
import csv
from bs4 import BeautifulSoup
BASE_DIR = os.path.dirname(os.path.realpath(__file__))
html_location = os.path.join(BASE_DIR, 'html')

file_list = os.listdir(html_location)

with open(os.path.join(BASE_DIR,'csv/review.csv'),'w',newline="") as csvfile:
    fieldname = ["Date","Rating","Review"]
    write = csv.DictWriter(csvfile,fieldnames=fieldname)
    write.writeheader()
    for file in file_list:
        filename = os.path.join(html_location,file)
        f = open(filename,'r')
        soup = BeautifulSoup(f.read(), 'html.parser')

        for divs in soup.findAll('div', attrs={'class': 'a-section review'}):
            review_date = divs.find("span", {"class": "a-size-base a-color-secondary review-date"}).text.strip()
            rating = divs.find("span", {"class": "a-icon-alt"}).text
            review_text = divs.find("span", {"class": "a-size-base review-text"}).text
            write.writerow({'Date':review_date,'Rating':rating,'Review':review_text})



from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(name='amazonreviewscrap',
      version='0.1',
      description='Amazon review scrapper',
      long_description ='Amazon review scrapper. Without any IP block It will work with selenium and bs4',
      classifiers=[
          "Programming Language :: Python :: 3.6",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
      ],
      keywords='amazon scrapper datascrap-amazon review-scrap-amazon',
      url='https://github.com/nayonacademy/amazon-review-scrapper',
      author='Shariful Islam Nayon',
      author_email='si.nayon@gmail.com',
      license='MIT',
      packages=['amazonreviewscrap'],
      install_requires=[
          'beautifulsoup4',
          'requests',
          'selenium',
          'webdriver-manager'
      ],
      include_package_data=True,
      zip_safe=False,
      test_suite='nose.collector',
      tests_require=['nose'],
      )
